Clazz.declarePackage("J.translation");
(function(){
var c$ = Clazz.declareType(J.translation, "PO", null);
})();
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
